pygeodesy.points._Basequence

Package pygeodesy :: Module points :: Class _Basequence |
[frames] | no frames]

# Class _Basequence

           object --+
                    |
        _abcoll.Sized --+
                        |
           object --+   |
                    |   |
     _abcoll.Iterable --+
                        |
           object --+   |
                    |   |
    _abcoll.Container --+
                        |
         _abcoll.Sequence --+
                            |
                           _Basequence

Known Subclasses:
  - LatLon2psxy
  - , _Array2LatLon

(INTERNAL) Base class.

Nested Classes
Inherited from `_abcoll.Sized`: `__metaclass__`

Instance Methods
copy(self, deep=False) Make a shallow or deep copy of this instance. |
dup(self, **items) Duplicate this instance, without replacing items. |
point(self, *attrs) Must be overloaded. |
Inherited from `_abcoll.Sequence`: `__contains__`, `__getitem__`, `__iter__`, `__reversed__`, `count`, `index` Inherited from `_abcoll.Sized`: `__len__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`

Class Methods
Inherited from `_abcoll.Sized`: `__subclasshook__`

Class Variables
Inherited from `_abcoll.Sequence`: `__abstractmethods__`

Properties
| epsilon Class `property` with a `.name` attribute.
| isNumpy2 Is this a Numpy2 wrapper?
| isPoints2 Is this a LatLon2 wrapper/converter?
| isTuple2 Is this a Tuple2 wrapper?
Inherited from `object`: `__class__`

Method Details

### copy (self, deep=False) |
Make a shallow or deep copy of this instance. Arguments: `deep` - If `True`, make a deep, otherwise a shallow copy (`bool`). Returns: The copy (`This class`).

### dup (self, **items) |
Duplicate this instance, without replacing items. Arguments: `items` - No attributes (not allowed). Returns: The duplicate (`This class`). Raises: `TypeError` - Any `items` invalid.

Property Details

### epsilon Class `property` with a `.name` attribute. Get method: epsilon(self) - Get the tolerance for equality tests (`float`). Set method: epsilon(self, tol) - Set the tolerance for equality tests (`scalar`).

### isNumpy2 Is this a Numpy2 wrapper? Get method: isNumpy2(self) - Is this a Numpy2 wrapper? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isPoints2 Is this a LatLon2 wrapper/converter? Get method: isPoints2(self) - Is this a LatLon2 wrapper/converter? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isTuple2 Is this a Tuple2 wrapper? Get method: isTuple2(self) - Is this a Tuple2 wrapper? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.